/* This file has been put into the public domain by its author.

   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
   EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
   MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
   IN NO EVENT SHALL THE AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR
   OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
   ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
   OTHER DEALINGS IN THE SOFTWARE.
*/

/* catan, catanf, catanl - complex arc tangent functions

   AUTHOR: Gregory Pietsch

   DESCRIPTION

   The functionality described on this reference page is aligned with the 
   ISO C standard. Any conflict between the requirements described here and 
   the ISO C standard is unintentional. This volume of POSIX.1-2017 defers 
   to the ISO C standard.

   These functions shall compute the complex arc tangent of z, with branch 
   cuts outside the interval [-i, +i] along the imaginary axis.

   RETURN VALUE

   These functions shall return the complex arc tangent value, in the range 
   of a strip mathematically unbounded along the imaginary axis and in the 
   interval [-pi/2, +pi/2] along the real axis.

   ERRORS

   No errors are defined.
*/

#include <complex.h>
#include "xmath.h"

double _Complex (catan) (double _Complex z)
{
  z = catanh (CMPLX (-cimag (z), creal (z)));
  return CMPLX (-cimag (z), creal (z));
}

float _Complex (catanf) (float _Complex z)
{
  z = catanhf (CMPLXF (-cimag (z), creal (z)));
  return CMPLXF (-cimag (z), creal (z));
}

long double _Complex (catanl) (long double _Complex z)
{
  z = catanhl (CMPLXL (-cimag (z), creal (z)));
  return CMPLXL (-cimag (z), creal (z));
}

/* END OF FILE */
